@@ -7,88 +7,19 @@ __END__
 
 =head1 \tgEFA
 
-Sjis-JA - Source code filter to escape ShiftJIS (Japanese document)
+Sjis-JA - Source code filter for ShiftJIS script (Japanese document)
 
-=head1 Tv
-
-   g: A
+=head1 ߂ĂJPerl
 
     XNvg ShiftJIS_script.pl ̒ɈȉLq...
       use Sjis;
-      use Sjis version;          --- Sjis.pm ̃o[W`FbNsꍇ
-      use Sjis qw(ord reverse);  --- ord, reverse ̊g@\gꍇ
-      use Sjis version qw(ord reverse);
-
-       no Sjis; ͗pł܂B
-
-    R}hvvgňȉ̂ꂩŎs
-      perl      ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
-      perl5     ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
-      perl55    ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
-      perl56    ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
-      perl58    ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
-      perl510   ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
-      perl512   ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
-      perl514   ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
-      perl516   ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
-      perl64    ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
-      aperl58   ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
-      aperl510  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
-      aperl512  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
-      aperl514  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
-      aperl516  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
-      sperl58   ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
-      sperl510  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
-      sperl512  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
-      sperl514  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
-      sperl516  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
-
-      ? * găChJ[h̎w肪ł܂
-      ' ` ' găNH[g邱Ƃł܂
-
-   g: B
 
     R}hvvgňȉ̂悤Ɏs
+      perl ShiftJIS_script.pl argv1 argv2 ...
 
-      C:\>perl  Sjis.pm  ShiftJIS_script.pl  >  Escaped_script.pl.e
-      C:\>perl  Escaped_script.pl.e
-
-      ShiftJIS_script.pl  --- ShiftJIS ŏꂽXNvg
-      Escaped_script.pl.e --- GXP[vꂽXNvg
-
-   g֐
-      Sjis::ord(...);
-      Sjis::reverse(...);
-      Sjis::length(...);
-      Sjis::substr(...);
-      Sjis::index(...);
-      Sjis::rindex(...);
-      CORE::chop(...);
-      CORE::ord(...);
-      CORE::reverse(...);
-      CORE::index(...);
-      CORE::rindex(...);
-
-   Perl5.6 G~[V(perl5.005̏ꍇ)
-      use warnings;
-      use warnings::register;
-
-   Perl5.16 G~[V
-      use feature qw(fc);
-
-   ȉ̓_~[֐Ƃ
-      utf8::upgrade(...);
-      utf8::downgrade(...);
-      utf8::encode(...);
-      utf8::decode(...);
-      utf8::is_utf8(...);
-      utf8::valid(...);
-      bytes::chr(...);
-      bytes::index(...);
-      bytes::length(...);
-      bytes::ord(...);
-      bytes::rindex(...);
-      bytes::substr(...);
+    XNvg ShiftJIS ŋLq邱ƂłAK\͂߂Ƃ perl 
+    e@\ ShiftJIS ɑΉ悤ɂȂ܂B
+    ֐ length ̒Pʂ̓oCĝ܂܂ŁAUTF8tO͎gp܂B
 
 =head1 v
 
@@ -205,11 +136,7 @@ GXP[v_قȂ܂B
    perl55   pmake.bat install --- perl5.005 ɃCXg[܂
    perl56   pmake.bat install --- perl5.006 ɃCXg[܂
    perl58   pmake.bat install --- perl5.008 ɃCXg[܂
-   perl510  pmake.bat install --- perl5.010 ɃCXg[܂
-   perl512  pmake.bat install --- perl5.012 ɃCXg[܂
-   perl514  pmake.bat install --- perl5.014 ɃCXg[܂
-   perl516  pmake.bat install --- perl5.016 ɃCXg[܂
-   perl64   pmake.bat install --- perl64    ɃCXg[܂
+   (ȉ)
 
    pmake.bat dist             --- CPAN zzppbP[W܂
    pmake.bat ptar.bat         --- ptar.bat 쐬܂
@@ -229,22 +156,135 @@ GXP[v_قȂ܂B
    perl514.bat           --- ϐ PATH ̐ݒȂ perl5.14 TĎs
    perl516.bat           --- ϐ PATH ̐ݒȂ perl5.16 TĎs
    perl64.bat            --- ϐ PATH ̐ݒȂ perl64   TĎs
+   perl64512.bat         --- ϐ PATH ̐ݒȂ perl5.12 (64rbg) TĎs
+   perl64514.bat         --- ϐ PATH ̐ݒȂ perl5.14 (64rbg) TĎs
+   perl64516.bat         --- ϐ PATH ̐ݒȂ perl5.16 (64rbg) TĎs
    aperl58.bat           --- ϐ PATH ̐ݒȂ ActivePerl 5.8  TĎs
    aperl510.bat          --- ϐ PATH ̐ݒȂ ActivePerl 5.10 TĎs
    aperl512.bat          --- ϐ PATH ̐ݒȂ ActivePerl 5.12 TĎs
    aperl514.bat          --- ϐ PATH ̐ݒȂ ActivePerl 5.14 TĎs
    aperl516.bat          --- ϐ PATH ̐ݒȂ ActivePerl 5.16 TĎs
+   aperl64512.bat        --- ϐ PATH ̐ݒȂ ActivePerl 5.12 (64rbg) TĎs
+   aperl64514.bat        --- ϐ PATH ̐ݒȂ ActivePerl 5.14 (64rbg) TĎs
+   aperl64516.bat        --- ϐ PATH ̐ݒȂ ActivePerl 5.16 (64rbg) TĎs
    sperl58.bat           --- ϐ PATH ̐ݒȂ Strawberry Perl 5.8  TĎs
    sperl510.bat          --- ϐ PATH ̐ݒȂ Strawberry Perl 5.10 TĎs
    sperl512.bat          --- ϐ PATH ̐ݒȂ Strawberry Perl 5.12 TĎs
    sperl514.bat          --- ϐ PATH ̐ݒȂ Strawberry Perl 5.14 TĎs
    sperl516.bat          --- ϐ PATH ̐ݒȂ Strawberry Perl 5.16 TĎs
-
+   sperl64512.bat        --- ϐ PATH ̐ݒȂ Strawberry Perl perl5.12 (64rbg) TĎs
+   sperl64514.bat        --- ϐ PATH ̐ݒȂ Strawberry Perl perl5.14 (64rbg) TĎs
+   sperl64516.bat        --- ϐ PATH ̐ݒȂ Strawberry Perl perl5.16 (64rbg) TĎs
    strict.pm_            --- _~[ strict.pm
    warnings.pm_          --- warnings.pm ̊ȈՔ
    warnings/register.pm_ --- warnings/register.pm ̊ȈՔ
    feature.pm_           --- _~[ feature.pm
 
+=head1 E߂ĂJPerl
+
+   g(1)
+
+    1. XNvg ShiftJIS_script.pl ̒Ɉȉ̂ꂩLq...
+
+      use Sjis;
+      use Sjis ver.sion;         --- Sjis.pm ̃o[W ver.sion ȏȂs
+      use Sjis ver.sion.0;       --- Sjis.pm ̃o[W ver.sion łȂ die 
+      use Sjis qw(ord reverse);  --- ord, reverse ̊g@\gꍇ
+      use Sjis ver.sion qw(ord reverse);
+      use Sjis ver.sion.0 qw(ord reverse);
+
+       no Sjis; ͗pł܂B
+
+    2. R}hvvgňȉ̂ꂩŎs
+
+      PATH ɐݒ肳ĂfBNg perl sꍇ
+      perl        ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+
+      Strawberry Perl, ActivePerl ̏ɗL𒲂ׂĐɌ perl s
+      perl55      ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      perl56      ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      perl58      ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      perl510     ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      perl512     ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      perl514     ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      perl516     ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      perl64512   ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      perl64514   ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      perl64516   ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+
+      ActivePerl gpꍇ
+      aperl58     ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      aperl510    ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      aperl512    ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      aperl514    ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      aperl516    ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      aperl64512  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      aperl64514  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      aperl64516  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+
+      Strawberry Perl gpꍇ
+      sperl58     ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      sperl510    ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      sperl512    ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      sperl514    ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      sperl516    ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      sperl64512  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      sperl64514  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      sperl64516  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+
+      悭g perl  perl5.bat ɐݒ肵Ďgꍇ
+      perl5       ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+
+      64rbgł perl sꍇ
+      perl64      ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+
+      ? * găChJ[h̎w肪ł܂
+      ' ` ' găNH[g邱Ƃł܂
+
+   g(2)
+
+    R}hvvgňȉ̂悤Ɏs
+
+      C:\>perl  Sjis.pm  ShiftJIS_script.pl  >  Escaped_script.pl.e
+      C:\>perl  Escaped_script.pl.e
+
+      ShiftJIS_script.pl  --- ShiftJIS ŏꂽXNvg
+      Escaped_script.pl.e --- GXP[vꂽXNvg
+
+   g֐
+      Sjis::ord(...);
+      Sjis::reverse(...);
+      Sjis::length(...);
+      Sjis::substr(...);
+      Sjis::index(...);
+      Sjis::rindex(...);
+      CORE::chop(...);
+      CORE::ord(...);
+      CORE::reverse(...);
+      CORE::index(...);
+      CORE::rindex(...);
+
+   Perl5.6 G~[V(perl5.005̏ꍇ)
+      use warnings;
+      use warnings::register;
+
+   Perl5.16 G~[V
+      use feature qw(fc);
+
+   ȉ̓_~[֐ƂėpӂĂ
+      utf8::upgrade(...);
+      utf8::downgrade(...);
+      utf8::encode(...);
+      utf8::decode(...);
+      utf8::is_utf8(...);
+      utf8::valid(...);
+      bytes::chr(...);
+      bytes::index(...);
+      bytes::length(...);
+      bytes::ord(...);
+      bytes::rindex(...);
+      bytes::substr(...);
+
 =head1 GXP[vɂʌ݊̊m
 
 ̃\tgEFA͉ߋ̂̂󂵂͂AɁuGXP[vvɂċ@\ǉ
@@ -314,7 +354,7 @@ Sjis.pm ͐K\̐擪Ƀ}`oCgAJ[Ot܂B
   --------------------------------------------------------------------------------
   O                  
   --------------------------------------------------------------------------------
-  m/regexp/               m/@{Esjis::anchor}(?:regexp).../
+  m/regexp/               m/${Esjis::anchor}(?:regexp).../
   --------------------------------------------------------------------------------
 
 =head1 2INebg̃GXP[v
@@ -338,8 +378,8 @@ NX}`oCgΉłɏ܂B
   --------------------------------------------------------------------------------
   m/...MULTIOCT+.../      m/...(?:MULTIOCT)+.../
   m/...[AN-EM].../        m/...(?:A[N-Z]|[B-D][A-Z]|E[A-M]).../
-  m/...\D.../             m/...@{Esjis::eD}.../
-  m/...[[:^digit:]].../   m/...@{Esjis::not_digit}.../
+  m/...\D.../             m/...${Esjis::eD}.../
+  m/...[[:^digit:]].../   m/...${Esjis::not_digit}.../
   --------------------------------------------------------------------------------
 
 =head1 Esjis::ignorecase() ̌Ăяo
@@ -359,17 +399,23 @@ Sjis.pm  /i Cq̑ Esjis::ignorecase() ̌ďo܂B
   --------------------------------------------------------------------------------
   O                  
   --------------------------------------------------------------------------------
-  /regexp/                / LQ @Esjis::matched/
-  m/regexp/               m/ LQ @Esjis::matched/
-  ?regexp?                m? LQ @Esjis::matched?
-  m?regexp?               m? LQ @Esjis::matched?
-  s/regexp//              ($_ =~ m/ LQ @Esjis::matched/) ?
-                          eval{ Esjis::s_matched(); local $^W=0; my $__r=qq//; $_="${1}$__r$'"; 1 } :
+  /regexp/                / LQ $Esjis::matched/
+  m/regexp/               m/ LQ $Esjis::matched/
+  ?regexp?                m? LQ $Esjis::matched?
+  m?regexp?               m? LQ $Esjis::matched?
+ 
+  $_ =~                   ($_ =~ m/ LQ $Esjis::matched/) ?
+  s/regexp/replacement/   eval{ Esjis::s_matched(); local $^W=0; my $__r=qq/replacement/; $_="${1}$__r$'"; 1 } :
                           undef
+ 
+  $_ !~                   ($_ !~ m/ LQ $Esjis::matched/) ?
+  s/regexp/replacement/   1 :
+                          eval{ Esjis::s_matched(); local $^W=0; my $__r=qq/replacement/; $_="${1}$__r$'"; undef }
+ 
   split(/regexp/)         Esjis::split(qr/regexp/)
   split(m/regexp/)        Esjis::split(qr/regexp/)
   split(qr/regexp/)       Esjis::split(qr/regexp/)
-  qr/regexp/              qr/ LQ @Esjis::matched/
+  qr/regexp/              qr/ LQ $Esjis::matched/
   --------------------------------------------------------------------------------
 
 =head1 oCgw̐K\
@@ -379,17 +425,23 @@ Sjis.pm  /i Cq̑ Esjis::ignorecase() ̌ďo܂B
   --------------------------------------------------------------------------------
   O                  
   --------------------------------------------------------------------------------
-  /regexp/b               /(?:regexp)@Esjis::matched/
-  m/regexp/b              m/(?:regexp)@Esjis::matched/
-  ?regexp?b               m?regexp@Esjis::matched?
-  m?regexp?b              m?regexp@Esjis::matched?
-  s/regexp//b             ($_ =~ m/(\G[\x00-\xFF]*?)(?:regexp)@Esjis::matched/) ?
-                          eval{ Esjis::s_matched(); local $^W=0; my $__r=qq//; $_="${1}$__r$'"; 1 } :
+  /regexp/b               /(?:regexp)$Esjis::matched/
+  m/regexp/b              m/(?:regexp)$Esjis::matched/
+  ?regexp?b               m?regexp$Esjis::matched?
+  m?regexp?b              m?regexp$Esjis::matched?
+ 
+  $_ =~                   ($_ =~ m/(\G[\x00-\xFF]*?)(?:regexp)$Esjis::matched/) ?
+  s/regexp/replacement/b  eval{ Esjis::s_matched(); local $^W=0; my $__r=qq/replacement/; $_="${1}$__r$'"; 1 } :
                           undef
+ 
+  $_ !~                   ($_ !~ m/(\G[\x00-\xFF]*?)(?:regexp)$Esjis::matched/) ?
+  s/regexp/replacement/b  1 :
+                          eval{ Esjis::s_matched(); local $^W=0; my $__r=qq/replacement/; $_="${1}$__r$'"; undef }
+ 
   split(/regexp/b)        split(qr/regexp/)
   split(m/regexp/b)       split(qr/regexp/)
   split(qr/regexp/b)      split(qr/regexp/)
-  qr/regexp/b             qr/(?:regexp)@Esjis::matched/
+  qr/regexp/b             qr/(?:regexp)$Esjis::matched/
   --------------------------------------------------------------------------------
 
 =head1 NX̃GXP[v
@@ -399,22 +451,22 @@ Sjis.pm  /i Cq̑ Esjis::ignorecase() ̌ďo܂B
   ---------------------------------------------------------------
   escape        class
   ---------------------------------------------------------------
-   .            @{Esjis::dot}
-                @{Esjis::dot_s}    (/s Cq)
+   .            ${Esjis::dot}
+                ${Esjis::dot_s}    (/s Cq)
   \d            [0-9]
   \s            [\x09\x0A\x0C\x0D\x20]
   \w            [0-9A-Z_a-z]
-  \D            @{Esjis::eD}
-  \S            @{Esjis::eS}
-  \W            @{Esjis::eW}
+  \D            ${Esjis::eD}
+  \S            ${Esjis::eS}
+  \W            ${Esjis::eW}
   \h            [\x09\x20]
   \v            [\x0A\x0B\x0C\x0D]
-  \H            @{Esjis::eH}
-  \V            @{Esjis::eV}
+  \H            ${Esjis::eH}
+  \V            ${Esjis::eV}
   \C            [\x00-\xFF]
   \X            X (̉pAX ł)
-  \R            @{Esjis::eR}
-  \N            @{Esjis::eN}
+  \R            ${Esjis::eR}
+  \N            ${Esjis::eN}
   ---------------------------------------------------------------
 
 l POSIX X^C̕NXĒ`Ă܂B
@@ -438,22 +490,22 @@ l POSIX X^C̕NXĒ`Ă܂B
                 [\x41-\x5A\x61-\x7A]     (/i Cq)
   [:word:]      [\x30-\x39\x41-\x5A\x5F\x61-\x7A]
   [:xdigit:]    [\x30-\x39\x41-\x46\x61-\x66]
-  [:^alnum:]    @{Esjis::not_alnum}
-  [:^alpha:]    @{Esjis::not_alpha}
-  [:^ascii:]    @{Esjis::not_ascii}
-  [:^blank:]    @{Esjis::not_blank}
-  [:^cntrl:]    @{Esjis::not_cntrl}
-  [:^digit:]    @{Esjis::not_digit}
-  [:^graph:]    @{Esjis::not_graph}
-  [:^lower:]    @{Esjis::not_lower}
-                @{Esjis::not_lower_i}    (/i Cq)
-  [:^print:]    @{Esjis::not_print}
-  [:^punct:]    @{Esjis::not_punct}
-  [:^space:]    @{Esjis::not_space}
-  [:^upper:]    @{Esjis::not_upper}
-                @{Esjis::not_upper_i}    (/i Cq)
-  [:^word:]     @{Esjis::not_word}
-  [:^xdigit:]   @{Esjis::not_xdigit}
+  [:^alnum:]    ${Esjis::not_alnum}
+  [:^alpha:]    ${Esjis::not_alpha}
+  [:^ascii:]    ${Esjis::not_ascii}
+  [:^blank:]    ${Esjis::not_blank}
+  [:^cntrl:]    ${Esjis::not_cntrl}
+  [:^digit:]    ${Esjis::not_digit}
+  [:^graph:]    ${Esjis::not_graph}
+  [:^lower:]    ${Esjis::not_lower}
+                ${Esjis::not_lower_i}    (/i Cq)
+  [:^print:]    ${Esjis::not_print}
+  [:^punct:]    ${Esjis::not_punct}
+  [:^space:]    ${Esjis::not_space}
+  [:^upper:]    ${Esjis::not_upper}
+                ${Esjis::not_upper_i}    (/i Cq)
+  [:^word:]     ${Esjis::not_word}
+  [:^xdigit:]   ${Esjis::not_xdigit}
   ---------------------------------------------------------------
 
 l \b  \B ߋperlƂ̌݊ۂ߂ɍĒ`Ă܂B
@@ -461,8 +513,8 @@ l \b  \B ߋperlƂ̌݊ۂ߂ɍĒ`Ă܂B
   ---------------------------------------------------------------
   escape      class
   ---------------------------------------------------------------
-  \b          @{Esjis::eb}
-  \B          @{Esjis::eB}
+  \b          ${Esjis::eb}
+  \B          ${Esjis::eB}
   ---------------------------------------------------------------
 
 t@C Esjis.pm ̒ňȉ̂悤ɒ`Ă܂B
@@ -470,34 +522,34 @@ t@C Esjis.pm ̒ňȉ̂悤ɒ`Ă܂B
   ---------------------------------------------------------------------------------------------------------------------------------------------------------
   class                    Definition
   ---------------------------------------------------------------------------------------------------------------------------------------------------------
-  @{Esjis::anchor}         qr{\G(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC])*?}
-  @{Esjis::dot}            qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x0A])}
-  @{Esjis::dot_s}          qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC])}
-  @{Esjis::eD}             qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC0-9])}
-  @{Esjis::eS}             qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x09\x0A\x0C\x0D\x20])}
-  @{Esjis::eW}             qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC0-9A-Z_a-z])}
-  @{Esjis::eH}             qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x09\x20])}
-  @{Esjis::eV}             qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x0A\x0B\x0C\x0D])}
-  @{Esjis::eR}             qr{(?:\x0D\x0A|[\x0A\x0D])}
-  @{Esjis::eN}             qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x0A])}
-  @{Esjis::not_alnum}      qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x30-\x39\x41-\x5A\x61-\x7A])}
-  @{Esjis::not_alpha}      qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x41-\x5A\x61-\x7A])}
-  @{Esjis::not_ascii}      qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x00-\x7F])}
-  @{Esjis::not_blank}      qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x09\x20])}
-  @{Esjis::not_cntrl}      qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x00-\x1F\x7F])}
-  @{Esjis::not_digit}      qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x30-\x39])}
-  @{Esjis::not_graph}      qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x21-\x7F])}
-  @{Esjis::not_lower}      qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x61-\x7A])}
-  @{Esjis::not_lower_i}    qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC])}
-  @{Esjis::not_print}      qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x20-\x7F])}
-  @{Esjis::not_punct}      qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x21-\x2F\x3A-\x3F\x40\x5B-\x5F\x60\x7B-\x7E])}
-  @{Esjis::not_space}      qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x09\x0A\x0B\x0C\x0D\x20])}
-  @{Esjis::not_upper}      qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x41-\x5A])}
-  @{Esjis::not_upper_i}    qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC])}
-  @{Esjis::not_word}       qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x30-\x39\x41-\x5A\x5F\x61-\x7A])}
-  @{Esjis::not_xdigit}     qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x30-\x39\x41-\x46\x61-\x66])}
-  @{Esjis::eb}             qr{(?:\A(?=[0-9A-Z_a-z])|(?<=[\x00-\x2F\x40\x5B-\x5E\x60\x7B-\xFF])(?=[0-9A-Z_a-z])|(?<=[0-9A-Z_a-z])(?=[\x00-\x2F\x40\x5B-\x5E\x60\x7B-\xFF]|\z))}
-  @{Esjis::eB}             qr{(?:(?<=[0-9A-Z_a-z])(?=[0-9A-Z_a-z])|(?<=[\x00-\x2F\x40\x5B-\x5E\x60\x7B-\xFF])(?=[\x00-\x2F\x40\x5B-\x5E\x60\x7B-\xFF]))}
+  ${Esjis::anchor}         qr{\G(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC])*?}
+  ${Esjis::dot}            qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x0A])}
+  ${Esjis::dot_s}          qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC])}
+  ${Esjis::eD}             qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC0-9])}
+  ${Esjis::eS}             qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x09\x0A\x0C\x0D\x20])}
+  ${Esjis::eW}             qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC0-9A-Z_a-z])}
+  ${Esjis::eH}             qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x09\x20])}
+  ${Esjis::eV}             qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x0A\x0B\x0C\x0D])}
+  ${Esjis::eR}             qr{(?:\x0D\x0A|[\x0A\x0D])}
+  ${Esjis::eN}             qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x0A])}
+  ${Esjis::not_alnum}      qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x30-\x39\x41-\x5A\x61-\x7A])}
+  ${Esjis::not_alpha}      qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x41-\x5A\x61-\x7A])}
+  ${Esjis::not_ascii}      qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x00-\x7F])}
+  ${Esjis::not_blank}      qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x09\x20])}
+  ${Esjis::not_cntrl}      qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x00-\x1F\x7F])}
+  ${Esjis::not_digit}      qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x30-\x39])}
+  ${Esjis::not_graph}      qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x21-\x7F])}
+  ${Esjis::not_lower}      qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x61-\x7A])}
+  ${Esjis::not_lower_i}    qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC])}
+  ${Esjis::not_print}      qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x20-\x7F])}
+  ${Esjis::not_punct}      qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x21-\x2F\x3A-\x3F\x40\x5B-\x5F\x60\x7B-\x7E])}
+  ${Esjis::not_space}      qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x09\x0A\x0B\x0C\x0D\x20])}
+  ${Esjis::not_upper}      qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x41-\x5A])}
+  ${Esjis::not_upper_i}    qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC])}
+  ${Esjis::not_word}       qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x30-\x39\x41-\x5A\x5F\x61-\x7A])}
+  ${Esjis::not_xdigit}     qr{(?:[\x81-\x9F\xE0-\xFC][\x00-\xFF]|[^\x81-\x9F\xE0-\xFC\x30-\x39\x41-\x46\x61-\x66])}
+  ${Esjis::eb}             qr{(?:\A(?=[0-9A-Z_a-z])|(?<=[\x00-\x2F\x40\x5B-\x5E\x60\x7B-\xFF])(?=[0-9A-Z_a-z])|(?<=[0-9A-Z_a-z])(?=[\x00-\x2F\x40\x5B-\x5E\x60\x7B-\xFF]|\z))}
+  ${Esjis::eB}             qr{(?:(?<=[0-9A-Z_a-z])(?=[0-9A-Z_a-z])|(?<=[\x00-\x2F\x40\x5B-\x5E\x60\x7B-\xFF])(?=[\x00-\x2F\x40\x5B-\x5E\x60\x7B-\xFF]))}
   ---------------------------------------------------------------------------------------------------------------------------------------------------------
 
 =head1 \N, \p, \P, \X ̃AGXP[v
@@ -505,17 +557,22 @@ t@C Esjis.pm ̒ňȉ̂悤ɒ`Ă܂B
 ̃\tgEFAɂĉp̐K\^V{ \N, \p, \P, \X ̐擪
 '\' 菜܂B̕@Œۉ㩂邱Ƃł܂B
 
+AGXP[v "{" GXP[v悤ɂŔA
+Deprecate literal unescaped "{" in regexes.
+http://perl5.git.perl.org/perl.git/commit/2a53d3314d380af5ab5283758219417c6dfa36e9
+ɂ̂łB
+
   ------------------------------------
   O           
   ------------------------------------
-  \N{CHARNAME}     N{CHARNAME}
-  \p{L}            p{L}
-  \p{^L}           p{^L}
-  \p{\^L}          p{\^L}
+  \N{CHARNAME}     N\{CHARNAME}
+  \p{L}            p\{L}
+  \p{^L}           p\{^L}
+  \p{\^L}          p\{\^L}
   \pL              pL
-  \P{L}            P{L}
-  \P{^L}           P{^L}
-  \P{\^L}          P{\^L}
+  \P{L}            P\{L}
+  \P{^L}           P\{^L}
+  \P{\^L}          P\{\^L}
   \PL              PL
   \X               X
   ------------------------------------
@@ -1126,7 +1183,7 @@ WW[̃t@C /Perl/site/lib/Sjis ɃRs[ 'use utf8;'
 =item * K\Kp镶̒̏
 
     Oq̂ƂAGXP[v̐K\ɂ̓}`oCgAJ[Ô
-    ߂̋Lq @{Esjis::anchor} ǉ܂A̒Ɋ܂܂ \G ̐
+    ߂̋Lq ${Esjis::anchor} ǉ܂A̒Ɋ܂܂ \G ̐
     ܂Bperl5.006, perl5.008, perl5.010, perl5.012, perl5.014, perl5.016 
     sꍇAΏە32,767oCg𒴂ʒuł̃}b`ׂƂ
     }b`܂BȂA̍ۂɃG[xo͂܂B
@@ -1865,8 +1922,36 @@ Programming Perl, 3rd ed. ꂽɂ́AUTF8 tO͐܂Ă炸APerl
 ȒPȎdȒPɂł悤ɐ݌vĂ܂B̃\tgEFÂ͓悤
 vO~O񋟂܂B
 
+=head1 ߂ĂPerl̂
+
+  Rs[^Ȋw҂̒ɂ(ɊҌ`҂)ے肷҂̂A
+ lԂƂ͕̂ς`̐SĂ̂Ȃ̂BŠ`͕Rł͂Ȃ
+ ̂ŁAЂǂc߂邱ƂȂɂ͕ȖʂɎʑ邱Ƃ͂łȂBߋ
+ 20Nȏɂ킽āARs[^Ҍ`҂͒𐫂̐_a삫A
+ オƁAނ̐M򂷂֗~IȐNƂȂĉB
+
+  ނ̔M󂾂Ⴂ̊]́AN̐Sނ̎vllɍ悤ɍ
+ ςāAN̎vlp^[̒z̕ɉ߂邱ƂB
+ ʂɉ܂ƂƂ́A܂т̂Ȃ݂ɂȂĂ܂Ƃ
+ B
+
+ --- ߂ĂPerl xviii
+
+  𓪒ɂ̎킾ƎvȂA̒ʂłBN̂悤ȏ󋵂D
+ 킯ł͂܂BłAPerl͓͂ƃGR[fBÖɊւāA
+ xXgsĂ܂BjZbgĂ蒼̂ȂA̎ɂ
+ Ȃɑ̌ƂȂ̂łB
+
+ --- ߂ĂPerl 6
+
 =head1 QlAN
 
+ PerlvO~O
+ Larry Wall, Randal L.Schwartz, ߓ Ð 
+ 1993N2 s
+ ISBN 4-89052-384-7
+ http://www.context.co.jp/~cond/books/old-books.html
+
  vO~OPerl 
  By Larry Wall, Tom Christiansen, Randal L. Schwartz, ߓ Ð 
  1997N12 s
@@ -1959,6 +2044,19 @@ vO~O񋟂܂B
  ISBN4-900900-65-6
  http://www.oreilly.co.jp/out/presuni/
 
+ ܂邲Perl! Vol.1
+  e, {BF, ɓ, 썇FT, M,  , Ί_, IR, ܂܂, r糒qm, ma.la, |ǔ, , mL, HR, vی, Vj, ̑a 
+ 2006N0825 
+ 232y[W
+ ISBN978-4-8443-2289-4
+ http://www.impressjapan.jp/books/2289
+
+ WEB+DB PRESS Vol.70
+ 2012N0824 
+ 200y[W
+ ISBN978-4-7741-5190-8
+ http://gihyo.jp/magazine/wdpress
+
  {񏈗
  Understanding Japanese Information Processing
  By Ken Lunde, t ,   
@@ -1996,18 +2094,46 @@ vO~O񋟂܂B
  ISBN978-4-87311-450-7
  http://www.oreilly.co.jp/books/9784873114507/
 
- PerlvO~O
- Larry Wall, Randal L.Schwartz, ߓ Ð 
- 1993N2s
- ISBN 4-89052-384-7
- http://www.context.co.jp/~cond/books/old-books.html
-
  JIST
  Ŗ ki Ғ
  1456 
  ISBN 4-542-20129-5
  http://www.webstore.jsa.or.jp/lib/lib.asp?fn=/manual/mnl01_12.htm
 
+ C^[lbg̕R[h
+  ,  F, ˑ N, O M 
+ 285 
+ ISBN 4-320-12038-8
+ http://www.kyoritsu-pub.co.jp/bookdetail/9784320120389
+
+ ̗j\ĂƓ{ҁ\
+  F,  fq 
+ 2006N210 s
+ 288y[W
+ ISBN 4-320-12102-7
+ http://www.kyoritsu-pub.co.jp/bookdetail/9784320121027
+
+ ̗j AWA
+ O M 
+ 2002N320 s
+ 377y[W
+ ISBN 4-320-12040-X
+ http://www.amazon.co.jp/gp/product/432012040X
+
+ UnicodeW
+ gj[EOn ,  au, CV O , ֌ T ďC
+ 2001N529 s
+ 455y[W
+ ISBN 4-7981-0030-7
+ http://www.seshop.com/product/detail/2276/
+
+ UnicodeɂJIS X 0213
+ c OY 
+ 2008N825 s
+ 200y[W
+ ISBN 978-4-89100-608-2
+ http://ec.nikkeibp.co.jp/item/books/A04500.html
+
  UNIX MAGAZINE
  1993N8
  172y[W
@@ -2022,8 +2148,8 @@ vO~O񋟂܂B
 
  Macintoshf[^pp
  Γc L 
- 230y[W
  1995N2 s
+ 230y[W
  ISBN 4-89563-408-6
 
  MPWvO~Ou
